@@ -1,6 +1,4 @@
-#!/usr/bin/env python3
-
-# SPDX-FileCopyrightText: 2020 Andrius Štikonas <andrius@stikonas.eu>
+# SPDX-FileCopyrightText: 2020-2021 Andrius Štikonas <andrius@stikonas.eu>
 # SPDX-License-Identifier: LGPL-3.0-or-later
 
 from datetime import datetime, timedelta
@@ -39,8 +37,9 @@ class NeoStat(SimpleNamespace):
         self.hold_off = self._data_.HOLD_OFF
         self.hold_on = self._data_.HOLD_ON
         self.hold_temp = self._data_.HOLD_TEMP
-        _hold_time = datetime.strptime(self._data_.HOLD_TIME, "%H:%M")
-        self.hold_time = timedelta(hours=_hold_time.hour, minutes=_hold_time.minute)
+        _hold_time = list(map(int, self._data_.HOLD_TIME.split(':'))) # HOLD_TIME can be up to 99:99
+        _hold_time_minutes = _hold_time[0] * 60 + _hold_time[1]
+        self.hold_time = timedelta(minutes=_hold_time_minutes)
         self.holiday = self._data_.HOLIDAY
         self.lock = self._data_.LOCK
         self.low_battery = self._data_.LOW_BATTERY
@@ -112,11 +111,11 @@ class NeoStat(SimpleNamespace):
         return result
 
     async def set_frost(self, state: bool):
-        result = await self._hub.frost(state, [self])
+        result = await self._hub.set_frost(state, [self])
         return result
 
     async def set_target_temperature(self, temperature: int):
-        result = await self._hub.set_temp(temperature, [self])
+        result = await self._hub.set_target_temperature(temperature, [self])
         return result
 
     async def set_diff(self, switching_differential: int):
@@ -128,3 +127,12 @@ class NeoStat(SimpleNamespace):
         result = await self._hub.rate_of_change([self])
         roc = result[self.name]
         return roc
+
+    async def set_timer_hold(self, state: bool, minutes: int):
+        """
+        Turns the output of timeclock on or off for certain duration
+
+        Works only with NeoStats in timeclock mode
+        """
+        result = await self._hub.set_timer_hold(state, minutes, [self])
+        return result
